@@ -57,12 +57,17 @@ class Bot:
 
     # <---- custom API actions start ----> #
 
-    async def send_photo(self, chat_id, photo, **kwargs):
+    async def delete_message(self,chat_id,message_id,revoke=True):
+        return await self.pyrogram.delete_messages(chat_id,message_id,revoke)
+
+    async def send_photo(self, chat_id:int, photo:str, **kwargs):
         dic = {
             'chat_id': chat_id,
             'photo': photo
         }
-        dic.update(kwargs)
+        dic.update(**kwargs)
+        if 'reply_markup' in kwargs:
+            dic.update({'reply_markup': json.dumps(kwargs.get('reply_markup').to_dict())})
         return await self._tg_request('sendPhoto', True, **dic)
 
     async def send_sticker(self, chat_id, sticker, **kwargs):
@@ -129,9 +134,9 @@ class Bot:
 
     # <---- COGS start ----> #
 
-    def command(self, name, aliases=None, usage=None, description=None, roles=None, ignore_filter=False):
+    def command(self, name, aliases=None, usage=None, description=None, roles=None, ignore_filter=False,has_arts=False):
         def decorator(func):
-            command = Command(func, name, description, aliases, usage, roles, ignore_filter)
+            command = Command(func, name, description, aliases, usage, roles, ignore_filter,has_arts=has_arts)
             self.add_command(name, command)
             if ignore_filter:
                 self.ignore_filter.append(command)
@@ -296,6 +301,8 @@ class Bot:
                     command.aliases = v.aliases
                     for al in v.aliases:
                         self.add_command(al, command)
+                if 'has_arts' in dir(v):
+                    command.has_arts = v.has_arts
                 self.add_command(v.__command__, command)
                 self.actions_from_cog.append(command)
             elif '__listener__' in dir(v):
